import logging

from .simulation import Simulation

logging.getLogger('name.of.library').addHandler(logging.NullHandler())
